@@ -7,7 +7,9 @@ from polly.errors import (
     EmptyCohortException,
     InvalidCohortAddition,
     InvalidCohortMergeOperation,
+    InvalidPathException,
 )
+import os
 import pandas as pd
 from deprecated import deprecated
 from polly.bridge_cohort import CohortRepoClass
@@ -142,13 +144,7 @@ instantiated.
         repo_name = self.bridge_obj._return_omixatlas_name(repo_key)
         if repo_name not in self._cohort_info:
             raise InvalidRepoException(repo_name)
-        for repo, dict in self._cohort_info.items():
-            if repo_name == repo:
-                if dict["file_structure"] == "single":
-                    entity_type = "dataset"
-                else:
-                    entity_type = "sample"
-        cohort_entity_type = entity_type
+        cohort_entity_type = self._assign_entity_type(repo_name, dataset_id)
         if "entity_type" in self._cohort_details:
             existing_entity_type = self._cohort_details.get("entity_type")
             if existing_entity_type != cohort_entity_type:
@@ -453,3 +449,52 @@ instantiated.
         self.bridge_obj._cohort_details = self.core_obj._cohort_details
         self._cohort_details = self.core_obj._cohort_details
         self._cohort_path = None
+
+    def _assign_entity_type(self, repo_name: str, dataset_id: str) -> str:
+        """
+        Function to return entity type
+        Input: repo_name(str) and dataset_id(str or list)
+        Returns: Entity_type('dataset' for single mapped repositories,\
+            'sample' for multiple mapped repositories.)
+        """
+        for repo, dict in self._cohort_info.items():
+            if repo_name == repo:
+                if dict["file_structure"] == "single":
+                    cohort_entity_type = "dataset"
+                elif dict["file_structure"] == "multiple":
+                    cohort_entity_type = "sample"
+                else:
+                    cohort_entity_type = self.bridge_obj._get_entity_type(
+                        repo_name, dataset_id, self._cohort_info
+                    )
+        return cohort_entity_type
+
+    def create_merged_gct(self, file_path: str, file_name="") -> None:
+        """
+          This function is used to merge all the gct files in a cohort into a single gct file.
+
+        ``Args:``
+            |  ``file_path(str):`` the system path where the gct file is to be written.
+            |  ``file_name(str):`` Optional Argument: Identifier for the merged file name, cohort name will be used by default.
+        """
+        self.core_obj._cohort_details = self._cohort_details
+        if self._cohort_details is None:
+            raise InvalidCohortOperationException
+        if "entity_type" not in self._cohort_details:
+            raise EmptyCohortException
+        if not isinstance(file_name, str):
+            raise InvalidParameterException("file_name")
+        isExists = os.path.exists(file_path)
+        if not isExists:
+            raise InvalidPathException
+        if file_name:
+            if not isinstance(file_name, str):
+                raise InvalidParameterException("file_name")
+            file_name = f"{file_name}.gct"
+        else:
+            # Fetching cohort name to be used as the file name
+            cohort_info = self.summarize_cohort()
+            cohort_name = cohort_info[0].get("cohort_name")
+            file_name = f"{cohort_name}.gct"
+        entity_type = self._cohort_details.get("entity_type")
+        self.core_obj.merge_gcts(entity_type, self._cohort_path, file_name, file_path)
